{% load i18n %}
<div id="utility_lang">
    <form id = "form_change_language" action="/i18n/setlang/" method="post">{% csrf_token %}        
	    {% for language in languages %}        
	        {% if not forloop.first %}
	            {%if separator %}
	                <span class = "lang_separator">
	                    {{separator}}
	                </span>
	            {%endif%}
	        {% endif %}
	        <input type="image" {% if language.code == LANGUAGE_CODE %}disabled="disabled"{% endif %} name="language" id = "lang_{{language.code}}" value="{{language.code}}" src="{{MEDIA_URL}}{{ language.flag }}" alt="{{language.name}}" />
	    {% endfor %}
    </form>
</div>